@@ -3,7 +3,7 @@ declare(strict_types=1);
 namespace ParagonIE\ConstantTime;
 
 /**
- *  Copyright (c) 2016 - 2017 Paragon Initiative Enterprises.
+ *  Copyright (c) 2016 - 2018 Paragon Initiative Enterprises.
  *  Copyright (c) 2014 Steve "Sc00bz" Thomas (steve at tobtu dot com)
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -35,17 +35,23 @@ abstract class Hex implements EncoderInterface
      * Convert a binary string into a hexadecimal string without cache-timing
      * leaks
      *
-     * @param string $bin_string (raw binary)
+     * @param string $binString (raw binary)
      * @return string
+     * @throws \TypeError
      */
-    public static function encode(string $bin_string): string
+    public static function encode(string $binString): string
     {
+        /** @var string $hex */
         $hex = '';
-        $len = Binary::safeStrlen($bin_string);
+        $len = Binary::safeStrlen($binString);
         for ($i = 0; $i < $len; ++$i) {
-            $chunk = \unpack('C', Binary::safeSubstr($bin_string, $i, 2));
+            /** @var array<int, int> $chunk */
+            $chunk = \unpack('C', Binary::safeSubstr($binString, $i, 1));
+            /** @var int $c */
             $c = $chunk[1] & 0xf;
+            /** @var int $b */
             $b = $chunk[1] >> 4;
+
             $hex .= pack(
                 'CC',
                 (87 + $b + ((($b - 10) >> 8) & ~38)),
@@ -59,17 +65,25 @@ abstract class Hex implements EncoderInterface
      * Convert a binary string into a hexadecimal string without cache-timing
      * leaks, returning uppercase letters (as per RFC 4648)
      *
-     * @param string $bin_string (raw binary)
+     * @param string $binString (raw binary)
      * @return string
+     * @throws \TypeError
      */
-    public static function encodeUpper(string $bin_string): string
+    public static function encodeUpper(string $binString): string
     {
+        /** @var string $hex */
         $hex = '';
-        $len = Binary::safeStrlen($bin_string);
+        /** @var int $len */
+        $len = Binary::safeStrlen($binString);
+
         for ($i = 0; $i < $len; ++$i) {
-            $chunk = \unpack('C', Binary::safeSubstr($bin_string, $i, 2));
+            /** @var array<int, int> $chunk */
+            $chunk = \unpack('C', Binary::safeSubstr($binString, $i, 2));
+            /** @var int $c */
             $c = $chunk[1] & 0xf;
+            /** @var int $b */
             $b = $chunk[1] >> 4;
+
             $hex .= pack(
                 'CC',
                 (55 + $b + ((($b - 10) >> 8) & ~6)),
@@ -83,17 +97,22 @@ abstract class Hex implements EncoderInterface
      * Convert a hexadecimal string into a binary string without cache-timing
      * leaks
      *
-     * @param string $hex_string
+     * @param string $hexString
      * @param bool $strictPadding
      * @return string (raw binary)
      * @throws \RangeException
      */
     public static function decode(string $hexString, bool $strictPadding = false): string
     {
+        /** @var int $hex_pos */
         $hex_pos = 0;
+        /** @var string $bin */
         $bin = '';
+        /** @var int $c_acc */
         $c_acc = 0;
+        /** @var int $hex_len */
         $hex_len = Binary::safeStrlen($hexString);
+        /** @var int $state */
         $state = 0;
         if (($hex_len & 1) !== 0) {
             if ($strictPadding) {
@@ -106,19 +125,27 @@ abstract class Hex implements EncoderInterface
             }
         }
 
+        /** @var array<int, ing> $chunk */
         $chunk = \unpack('C*', $hexString);
         while ($hex_pos < $hex_len) {
             ++$hex_pos;
+            /** @var int $c */
             $c = $chunk[$hex_pos];
+            /** @var int $c_num */
             $c_num = $c ^ 48;
+            /** @var int $c_num0 */
             $c_num0 = ($c_num - 10) >> 8;
+            /** @var int $c_alpha */
             $c_alpha = ($c & ~32) - 55;
+            /** @var int $c_alpha0 */
             $c_alpha0 = (($c_alpha - 10) ^ ($c_alpha - 16)) >> 8;
+
             if (($c_num0 | $c_alpha0) === 0) {
                 throw new \RangeException(
                     'hexEncode() only expects hexadecimal characters'
                 );
             }
+            /** @var int $c_val */
             $c_val = ($c_num0 & $c_num) | ($c_alpha & $c_alpha0);
             if ($state === 0) {
                 $c_acc = $c_val * 16;
